==> configurable-3.2.11%2B1.21.10-fabric-sources.jar: com/bawnorton/configurable/data/ConfigurableDataGen.java <==
package com.bawnorton.configurable.data;

//? if fabric {
import dev.kikugie.fletching_table.annotation.fabric.Entrypoint;
import net.fabricmc.fabric.api.datagen.v1.DataGeneratorEntrypoint;
import net.fabricmc.fabric.api.datagen.v1.FabricDataGenerator;
import net.minecraft.class_2561;
import net.minecraft.class_3264;
import net.minecraft.class_3272;
import net.minecraft.class_3797;
import net.minecraft.class_6497;
import net.minecraft.class_7796;
import java.util.Optional;

@Entrypoint("fabric-datagen")
public final class ConfigurableDataGen implements DataGeneratorEntrypoint {
	@Override
	public void onInitializeDataGenerator(FabricDataGenerator fabricDataGenerator) {
		FabricDataGenerator.Pack mainPack = fabricDataGenerator.createPack();
		mainPack.addProvider((FabricDataGenerator.Pack.Factory<class_7796>) output -> new class_7796(output)
				.method_46185(
						//? if >=1.21.10 {
						class_3272.field_61156,
						new class_3272(
								class_2561.method_43470("${mod_description}"),
								class_6497.method_37956(
										class_3797.field_25319.method_70592(class_3264.field_14190),
										class_3797.field_25319.method_70592(class_3264.field_14190)
								).getOrThrow()
						)
						//?} else {
						/*PackMetadataSection.TYPE,
						new PackMetadataSection(
								Component.literal("${mod_description}"),
								//? if >=1.21.8 {
								DetectedVersion.BUILT_IN.packVersion(PackType.SERVER_DATA),
								//?} else {
								/^DetectedVersion.BUILT_IN.getPackVersion(PackType.SERVER_DATA),
								^///?}
								Optional.empty()
						)
						*///?}
				)
		);
	}
}
//?} else {
/*import com.bawnorton.configurable.ConfigurableMain;
import net.minecraft.DetectedVersion;
import net.minecraft.data.DataGenerator;
import net.minecraft.data.PackOutput;
import net.minecraft.data.metadata.PackMetadataGenerator;
import net.minecraft.network.chat.Component;
import net.minecraft.server.packs.PackType;
import net.minecraft.server.packs.metadata.pack.PackMetadataSection;
import net.minecraft.util.InclusiveRange;
import net.neoforged.bus.api.SubscribeEvent;
import net.neoforged.fml.common.EventBusSubscriber;
import net.neoforged.neoforge.data.event.GatherDataEvent;

@EventBusSubscriber(modid = ConfigurableMain.MOD_ID)
public final class ConfigurableDataGen {
	@SubscribeEvent
	//? if >=1.21.8 {
	public static void gatherServerData(GatherDataEvent.Server event) {
		DataGenerator gen = event.getGenerator();
	//?} else {
	/^public static void gatherData(GatherDataEvent event) {
		DataGenerator gen = event.getGenerator();
	^///?}
		PackOutput mainPack = gen.getPackOutput();
		gen.addProvider(true, new PackMetadataGenerator(mainPack)
				.add(
						//? if >=1.21.10 {
						PackMetadataSection.SERVER_TYPE,
						new PackMetadataSection(
								Component.literal("${mod_description}"),
								InclusiveRange.create(
										DetectedVersion.BUILT_IN.packVersion(PackType.SERVER_DATA),
										DetectedVersion.BUILT_IN.packVersion(PackType.SERVER_DATA)
								).getOrThrow()
						)
						//?} else {
						/^PackMetadataSection.TYPE,
						new PackMetadataSection(
								Component.literal("${mod_description}"),
								//? if >=1.21.8 {
								DetectedVersion.BUILT_IN.packVersion(PackType.SERVER_DATA),
								//?} else {
								/^¹DetectedVersion.BUILT_IN.getPackVersion(PackType.SERVER_DATA),
								¹^///?}
								java.util.Optional.empty()
						)
						^///?}
				)
		);
	}
}
*///?}

==> configurable-3.2.12%2B1.21.1-fabric-sources.jar: com/bawnorton/configurable/data/ConfigurableDataGen.java <==
package com.bawnorton.configurable.data;

//? if fabric {
import dev.kikugie.fletching_table.annotation.fabric.Entrypoint;
import net.fabricmc.fabric.api.datagen.v1.DataGeneratorEntrypoint;
import net.fabricmc.fabric.api.datagen.v1.FabricDataGenerator;
import net.minecraft.class_2561;
import net.minecraft.class_3264;
import net.minecraft.class_3272;
import net.minecraft.class_3797;
import net.minecraft.class_7796;
import java.util.Optional;

@Entrypoint("fabric-datagen")
public final class ConfigurableDataGen implements DataGeneratorEntrypoint {
	@Override
	public void onInitializeDataGenerator(FabricDataGenerator fabricDataGenerator) {
		FabricDataGenerator.Pack mainPack = fabricDataGenerator.createPack();
		mainPack.addProvider((FabricDataGenerator.Pack.Factory<class_7796>) output -> new class_7796(output)
				.method_46185(
						//? if >=1.21.10 {
						/*PackMetadataSection.SERVER_TYPE,
						new PackMetadataSection(
								Component.literal("${mod_description}"),
								InclusiveRange.create(
										DetectedVersion.BUILT_IN.packVersion(PackType.SERVER_DATA),
										DetectedVersion.BUILT_IN.packVersion(PackType.SERVER_DATA)
								).getOrThrow()
						)
						*///?} else {
						class_3272.field_14202,
						new class_3272(
								class_2561.method_43470("${mod_description}"),
								//? if >=1.21.8 {
								/*DetectedVersion.BUILT_IN.packVersion(PackType.SERVER_DATA),
								*///?} else {
								class_3797.field_25319.method_48017(class_3264.field_14190),
								//?}
								Optional.empty()
						)
						//?}
				)
		);
	}
}
//?} else {
/*import com.bawnorton.configurable.ConfigurableMain;
import net.minecraft.DetectedVersion;
import net.minecraft.data.DataGenerator;
import net.minecraft.data.PackOutput;
import net.minecraft.data.metadata.PackMetadataGenerator;
import net.minecraft.network.chat.Component;
import net.minecraft.server.packs.PackType;
import net.minecraft.server.packs.metadata.pack.PackMetadataSection;
import net.minecraft.util.InclusiveRange;
import net.neoforged.bus.api.SubscribeEvent;
import net.neoforged.fml.common.EventBusSubscriber;
import net.neoforged.neoforge.data.event.GatherDataEvent;

@EventBusSubscriber(modid = ConfigurableMain.MOD_ID)
public final class ConfigurableDataGen {
	@SubscribeEvent
	//? if >=1.21.8 {
	public static void gatherServerData(GatherDataEvent.Server event) {
		DataGenerator gen = event.getGenerator();
	//?} else {
	/^public static void gatherData(GatherDataEvent event) {
		DataGenerator gen = event.getGenerator();
	^///?}
		PackOutput mainPack = gen.getPackOutput();
		gen.addProvider(true, new PackMetadataGenerator(mainPack)
				.add(
						//? if >=1.21.10 {
						PackMetadataSection.SERVER_TYPE,
						new PackMetadataSection(
								Component.literal("${mod_description}"),
								InclusiveRange.create(
										DetectedVersion.BUILT_IN.packVersion(PackType.SERVER_DATA),
										DetectedVersion.BUILT_IN.packVersion(PackType.SERVER_DATA)
								).getOrThrow()
						)
						//?} else {
						/^PackMetadataSection.TYPE,
						new PackMetadataSection(
								Component.literal("${mod_description}"),
								//? if >=1.21.8 {
								DetectedVersion.BUILT_IN.packVersion(PackType.SERVER_DATA),
								//?} else {
								/^¹DetectedVersion.BUILT_IN.getPackVersion(PackType.SERVER_DATA),
								¹^///?}
								java.util.Optional.empty()
						)
						^///?}
				)
		);
	}
}
*///?}
